km3pipe\.io\.H5Chain
====================

.. currentmodule:: km3pipe.io

.. autoclass:: H5Chain

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~H5Chain.__init__
      ~H5Chain.close
   
   

   
   
   